@@ -1,14 +1,12 @@
 package Pcore::API::Map::Method::Update;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::API::Map::Method];
 
 has '+use_fields' => ( default => 'all', init_arg => undef );
 has '+write_client_id' => ( default => 1 );
 
-no Pcore;
-
 1;
 __END__
 =pod
