@@ -9,20 +9,17 @@ has share_dir    => ( is => 'ro', isa => Str,  required => 1 );   # absolute pat
 
 has module => ( is => 'lazy', isa => InstanceOf ['Pcore::Util::Perl::Module'], predicate => 1 );
 
-has build_info => ( is => 'lazy', isa => Maybe [HashRef], clearer => 1, init_arg => undef );
-has cfg => ( is => 'lazy', isa => HashRef, clearer => 1, init_arg => undef );
-has name     => ( is => 'lazy', isa => Str,  init_arg => undef );                   # Dist-Name
+has cfg => ( is => 'lazy', isa => HashRef, clearer => 1, init_arg => undef );    # dist.perl
+has docker_cfg => ( is => 'lazy', isa => Maybe [HashRef], clearer => 1, init_arg => undef );    # docker.json
+has name     => ( is => 'lazy', isa => Str,  init_arg => undef );                               # Dist-Name
 has is_pcore => ( is => 'lazy', isa => Bool, init_arg => undef );
-has is_main  => ( is => 'ro',   isa => Bool, default  => 0, init_arg => undef );    # main process dist
-
-has version => ( is => 'lazy', isa => Object, clearer => 1, init_arg => undef );
-has last_release_version => ( is => 'lazy', isa => Maybe [Object], clearer => 1, init_arg => undef );
-has revision   => ( is => 'lazy', isa => Str, clearer => 1, init_arg => undef );
-has build_date => ( is => 'lazy', isa => Str, clearer => 1, init_arg => undef );
-has has_uncommited_changes => ( is => 'lazy', isa => Maybe [Bool], clearer => 1, init_arg => undef );    # undef - unknown
-has scm => ( is => 'lazy', isa => Maybe [ InstanceOf ['Pcore::Src::SCM'] ], init_arg => undef );
-
+has is_main  => ( is => 'ro',   isa => Bool, default  => 0, init_arg => undef );                # main process dist
+has scm => ( is => 'lazy', isa => Maybe [ InstanceOf ['Pcore::API::SCM'] ], init_arg => undef );
 has build => ( is => 'lazy', isa => InstanceOf ['Pcore::Dist::Build'], init_arg => undef );
+has id      => ( is => 'lazy', isa => HashRef, clearer => 1, init_arg => undef );
+has version => ( is => 'lazy', isa => Object,  clearer => 1, init_arg => undef );
+has is_commited => ( is => 'lazy', isa => Maybe [Bool],     init_arg => undef );
+has releases    => ( is => 'lazy', isa => Maybe [ArrayRef], init_arg => undef );
 
 around new => sub ( $orig, $self, $dist ) {
 
@@ -157,7 +154,7 @@ sub find_dist_root ( $self, $path ) {
 }
 
 sub dir_is_dist ( $self, $path ) {
-    return -f $path . '/share/dist.perl' && $path !~ m[/share/pcore/\z]sm ? 1 : 0;
+    return -f $path . '/share/dist.perl' && $path !~ m[/share/pcore/dist/\z]sm ? 1 : 0;
 }
 
 # CONSTRUCTOR
@@ -188,14 +185,18 @@ sub _build_module ($self) {
     return $module;
 }
 
-sub _build_build_info ($self) {
-    return -f $self->share_dir . 'build.perl' ? P->cfg->load( $self->share_dir . 'build.perl' ) : undef;
-}
-
 sub _build_cfg ($self) {
     return P->cfg->load( $self->share_dir . 'dist.perl' );
 }
 
+sub _build_docker_cfg ($self) {
+    if ( -f $self->share_dir . 'docker.json' ) {
+        return P->cfg->load( $self->share_dir . 'docker.json' );
+    }
+
+    return;
+}
+
 sub _build_name ($self) {
     return $self->cfg->{dist}->{name};
 }
@@ -204,104 +205,76 @@ sub _build_is_pcore ($self) {
     return $self->name eq 'Pcore';
 }
 
-sub _build_version ($self) {
-    if ( $self->is_installed ) {
-        return version->new( $self->build_info->{version} );
-    }
-    else {
-        return $self->module->version;
-    }
-}
-
-sub _build_last_release_version ($self) {
-    if ( $self->scm ) {
-        if ( my @releases = sort { $b cmp $a } grep {/v\d+[.]\d+[.]\d+/sm} $self->scm->server->cmd(qw[tags -q])->{o}->@* ) {
-            return version->parse( $releases[0] );
-        }
-        else {
-            return version->parse('v0.0.0');
-        }
-    }
-    else {
-        return;
-    }
-}
-
-sub _build_revision ($self) {
-    my $revision = 0;
-
-    if ( $self->is_installed ) {
-        $revision = $self->build_info->{revision};
-    }
-    elsif ( $self->scm ) {
-        $revision = $self->scm->server->cmd(qw[id -i])->{o}->[0];
-    }
-    elsif ( $self->root && -f $self->root . '.hg_archival.txt' ) {
-        my $info = P->file->read_bin( $self->root . '.hg_archival.txt' );
-
-        if ( $info->$* =~ /^node:\s+([[:xdigit:]]+)$/sm ) {
-            $revision = $1;
-        }
-    }
-
-    return $revision;
-}
-
-sub _build_build_date ($self) {
-    if ( $self->is_installed ) {
-        return $self->build_info->{build_date};
-    }
-    else {
-        return P->date->now_utc->to_string;
-    }
-}
-
-sub _build_has_uncommited_changes ($self) {
-    if ( $self->scm ) {
-        if ( $self->scm->server->cmd(qw[status -mardu --subrepos])->%* ) {
-            return 1;
-        }
-        else {
-            return 0;
-        }
-    }
-    else {
-        return;
-    }
-}
-
 sub _build_scm ($self) {
     return if $self->is_installed;
 
-    return P->class->load('Pcore::Src::SCM')->new( $self->root );
+    return P->class->load('Pcore::API::SCM')->new( $self->root );
 }
 
 sub _build_build ($self) {
     return P->class->load('Pcore::Dist::Build')->new( { dist => $self } );
 }
 
-sub create_build_info ($self) {
-    my $data = {
-        version    => $self->version->normal,
-        revision   => $self->revision,
-        build_date => $self->build_date,
+sub _build_id ($self) {
+    my $id = {
+        node                     => undef,
+        tags                     => undef,
+        bookmark                 => undef,
+        branch                   => undef,
+        desc                     => undef,
+        date                     => undef,
+        current_release          => undef,
+        current_release_distance => undef,
     };
 
-    return P->data->to_perl( $data, readable => 1 );
+    if ( !$self->is_installed && $self->scm ) {
+        if ( my $scm_id = $self->scm->scm_id ) {
+            $id->@{ keys $scm_id->{result}->%* } = values $scm_id->{result}->%*;
+        }
+
+        if ( $id->{current_release} && defined $id->{current_release_distance} && $id->{current_release_distance} == 1 ) {
+            $id->{current_release_distance} = 0 if $id->{desc} =~ /added tag.+$id->{current_release}/smi;
+        }
+    }
+    elsif ( -f $self->share_dir . 'dist_id.perl' ) {
+        $id = P->cfg->load( $self->share_dir . 'dist_id.perl' );
+    }
+
+    $id->{date} = P->date->from_string( $id->{date} )->at_utc if defined $id->{date};
+
+    return $id;
+}
+
+sub _build_version ($self) {
+    return $self->module->version;
+}
+
+sub _build_is_commited ($self) {
+    if ( !$self->is_installed && $self->scm && ( my $scm_is_commited = $self->scm->scm_is_commited ) ) {
+        return $scm_is_commited->{result};
+    }
+
+    return;
+}
+
+sub _build_releases ($self) {
+    if ( !$self->is_installed && $self->scm && ( my $scm_releases = $self->scm->scm_releases ) ) {
+        return $scm_releases->{result};
+    }
+
+    return;
 }
 
 sub clear ($self) {
+
+    # clear version
     $self->module->clear if $self->has_module;
 
-    $self->clear_build_info;
+    $self->clear_id;
 
     $self->clear_cfg;
 
-    $self->clear_version;
-
-    $self->clear_revision;
-
-    $self->clear_build_date;
+    $self->clear_docker_cfg;
 
     return;
 }
@@ -310,17 +283,13 @@ sub clear ($self) {
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
 ## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 110, 160             │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 261                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 218, 237, 261        │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 218                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 107, 157             | ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        |
+## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
+## |    3 | 232                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
